---
title: <span class="badge object-type-scalar"></span> SquareMiles
---
# <span class="badge object-type-scalar"></span> SquareMiles

Area: Square Miles (mi²)

## Definition

```python
# Area: Square Miles (mi²)
SquareMiles: typing.Literal["areaMI2"] = "areaMI2"
```
